"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Highlighter_1 = require("./Highlighter");
const rangeContents = require("./rangeContents");
const selection = require("./selection");
describe('Reference elements', () => {
    test('resolve', () => {
        document.body.innerHTML = `
      <div id="container">
        <div id="referenceElement1"></div>
        <div id="referenceElement2"></div>
        <div id="referenceElement3"></div>
      </div>
    `;
        const container = document.getElementById('container');
        const reference = document.getElementById('referenceElement2');
        if (!container) {
            throw new Error('cannot find container');
        }
        const highlighter = new Highlighter_1.default(container);
        expect(highlighter.getReferenceElement('referenceElement2')).toEqual(reference);
    });
    test('do not resolve outside the container', () => {
        document.body.innerHTML = `
      <div>
        <div id="referenceElement1"></div>
        <div id="container">
          <div id="referenceElement2"></div>
          <div id="referenceElement3"></div>
        </div>
      </div>
    `;
        const container = document.getElementById('container');
        if (!container) {
            throw new Error('can\'t find container');
        }
        const highlighter = new Highlighter_1.default(container);
        expect(highlighter.getReferenceElement('referenceElement1')).toEqual(null);
    });
});
describe('onSelect', () => {
    let getSelectionSpy;
    let snapSelectionSpy;
    let rangeContentsStringSpy;
    beforeEach(() => {
        getSelectionSpy = jest.spyOn(document, 'getSelection');
        snapSelectionSpy = jest.spyOn(selection, 'snapSelection');
        rangeContentsStringSpy = jest.spyOn(rangeContents, 'rangeContentsString');
        rangeContentsStringSpy.mockImplementation(() => '');
    });
    afterEach(() => {
        getSelectionSpy.mockRestore();
        snapSelectionSpy.mockRestore();
        rangeContentsStringSpy.mockRestore();
    });
    it('returns a highlight with the snapped range, even if document selection returns something completely different (looking at you safari)', () => {
        let highlight;
        const highlighter = new Highlighter_1.default(document.createElement('div'), { onSelect: (_, newHighlight) => highlight = newHighlight });
        const inputSelection = new Selection();
        const selectionRange = new Range();
        const snappedRange = new Range();
        Object.defineProperty(inputSelection, 'isCollapsed', { value: false });
        inputSelection.getRangeAt = jest.fn(() => selectionRange);
        snapSelectionSpy.mockImplementation(() => snappedRange);
        getSelectionSpy.mockImplementation(() => inputSelection);
        const e = document.createEvent('MouseEvents');
        e.initEvent('mouseup', true, true);
        highlighter.container.dispatchEvent(e);
        if (highlight === undefined) {
            expect(highlight).toBeDefined();
        }
        else {
            expect(highlight.range).not.toEqual(selectionRange);
            expect(highlight.range).toEqual(snappedRange);
        }
    });
});
//# sourceMappingURL=Highlighter.test.js.map