/**
 * OpenStax Highlights API
 * The highlights API for OpenStax.  Requests to this API should include `application/json` in the `Accept` header.  The desired API version is specified in the request URL, e.g. `[domain]/highlights/api/v0/highlights`. While the API does support a default version, that version will change over time and therefore should not be used in production code!
 *
 * The version of the OpenAPI document: 0.1.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 *
 * @export
 * @interface Highlight
 */
export interface Highlight {
    /**
     * The highlight ID.
     * @type {string}
     * @memberof Highlight
     */
    id: string;
    /**
     * The type of content that contains the highlight.
     * @type {string}
     * @memberof Highlight
     */
    sourceType?: HighlightSourceTypeEnum;
    /**
     * The ID of the source document in which the highlight is made.  Has source_type-specific constraints (e.g. all lowercase UUID for the \'openstax_page\' source_type).  Because source_ids are passed to query endpoints as comma-separated values, they cannot contain commas.
     * @type {string}
     * @memberof Highlight
     */
    sourceId?: string;
    /**
     * The ID of the container for the source in which the highlight is made.  Varies depending on source_type (e.g. is the lowercase, versionless book UUID for the \'openstax_page\' source_type).
     * @type {string}
     * @memberof Highlight
     */
    scopeId?: string;
    /**
     * The ID of the highlight immediately before this highlight.  May be null if there are no preceding highlights in this source.
     * @type {string}
     * @memberof Highlight
     */
    prevHighlightId?: string;
    /**
     * The ID of the highlight immediately after this highlight.  May be null if there are no following highlights in this source.
     * @type {string}
     * @memberof Highlight
     */
    nextHighlightId?: string;
    /**
     * The name of the highlight color.  Corresponding RGB values for different states (e.g. focused, passive) are maintained in the client.
     * @type {string}
     * @memberof Highlight
     */
    color?: HighlightColorEnum;
    /**
     * The anchor of the highlight.
     * @type {string}
     * @memberof Highlight
     */
    anchor?: string;
    /**
     * The highlighted content.
     * @type {string}
     * @memberof Highlight
     */
    highlightedContent?: string;
    /**
     * The note attached to the highlight.
     * @type {string}
     * @memberof Highlight
     */
    annotation?: string;
    /**
     * Location strategies for the highlight. Items should have a schema matching the strategy schemas that have been defined. (`XpathRangeSelector` or `TextPositionSelector`).
     * @type {Array<object>}
     * @memberof Highlight
     */
    locationStrategies?: Array<object>;
    /**
     * A number whose relative value gives the highlight\'s order within the source. Its value has no meaning on its own.
     * @type {number}
     * @memberof Highlight
     */
    readonly orderInSource?: number;
}
export declare function HighlightFromJSON(json: any): Highlight;
export declare function HighlightFromJSONTyped(json: any, ignoreDiscriminator: boolean): Highlight;
export declare function HighlightToJSON(value?: Highlight | null): any;
/**
* @export
* @enum {string}
*/
export declare enum HighlightSourceTypeEnum {
    OpenstaxPage = "openstax_page"
}
/**
* @export
* @enum {string}
*/
export declare enum HighlightColorEnum {
    Yellow = "yellow",
    Green = "green",
    Blue = "blue",
    Purple = "purple",
    Red = "red"
}
